<?php
/**
 * Scripts Dequeuer Backend Settings
 *
 */

class Script_Dequeuer_Backend_Settings {

	function __construct() {
		add_action( 'admin_menu', array( $this, 'add_plugin_settings_menu' ) );
		add_action( 'admin_init', array( $this, 'register_settings' ) );
	}

	function add_plugin_settings_menu() {
		// add_options_page( $page_title, $menu_title, $capability, $menu_slug, $function )
		add_options_page( 'Scripts Dequeuer Backend', 'Scripts Dequeuer Backend', 'manage_options', 'scripts-dequeuer-backend', array($this, 'sd_create_plugin_settings_page') );
	}

	function sd_create_plugin_settings_page() {
	?>
        <div class="wrap">

            <form method="post" action="options.php">
                <?php
                // Output all hidden fields
				settings_fields( 'sdequeuerbe-settings-group' );
                ?>

                <div class="wrap">
                    <h1 class="sd-settings-title"><?php esc_attr_e( 'Scripts Dequeuer Backend Settings', 'sdequeuerbe' ); ?></h1>

                    <?php
					global $wp_scripts, $wp_styles;
			
                    $options 				= get_option( 'sdequeuerbe_options' );
                    $sdbe_scripts_selected 	= ! empty( $options['sdbe_scripts_selected'] ) ? explode( ',', $options['sdbe_scripts_selected'] ) : '';
                    $sdbe_styles_selected 	= ! empty( $options['sdbe_styles_selected'] ) ? explode( ',', $options['sdbe_styles_selected'] ) : '';

                    $sc_sel_li = '';
                    $st_sel_li = '';

                    // Create items for scripts in dequeue list
                    if ( is_array( $sdbe_scripts_selected ) && ! empty( $sdbe_scripts_selected ) ) {
                        $sc_sel_li = '';
                        foreach( $sdbe_scripts_selected as $handle ) {
                            $sc_sel_li .= sprintf( '<li data-handle="%1$s">%1$s</li>', $handle );
                        }
                    }

                    else {
                        $sc_sel_li = '<li class="no-script">' . esc_attr__( 'No scripts added to dequeue.', 'sdequeuerbe' ) . '</li>';
                    }

                    // Create items for styles in dequeue list
                    if ( is_array( $sdbe_styles_selected ) && ! empty( $sdbe_styles_selected ) ) {
                        $st_sel_li = '';
                        foreach( $sdbe_styles_selected as $handle ) {
                            $st_sel_li .= sprintf( '<li data-handle="%1$s">%1$s</li>', $handle );
                        }
                    }

                    else {
                        $st_sel_li = '<li class="no-script">' . esc_attr__( 'No stylesheets added to dequeue.', 'sdequeuerbe' ) . '</li>';
                    }

                    ?>
                    <div class="sd-tabber">
                        <ul class="sd-tabs">
                            <li><a href="#sdbe_scripts" class="sd-tab-active" id="sdbe_scripts-tab"><?php echo esc_attr_x( 'Scripts', 'settings tab title', 'sdequeuerbe' ); ?></a></li>
                            <li><a href="#sdbe_styles" id="sdbe_styles-tab"><?php echo esc_attr_x( 'Styles', 'settings tab title', 'sdequeuerbe' ); ?></a></li>
                        </ul>
                        <div id="sdbe_scripts" class="sd-tabbed-content first">
                            <div class="sd-row">
                                <div class="sd-col col-66">
                                <?php echo '<div id="scbe-file-table" class="file-table-wrap-be">
            <h3>' . esc_html__( 'Scripts detected in backend', 'sdequeuerbe' ) . '<span id="script-detected-count" class="sd-count">' . count( $wp_scripts->groups ) . '</span><span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'Select scripts to add to dequeue list and then Save Changes.', 'sdequeuerbe' ) . '</span></span><a id="select-all-scripts-be" href="#" class="select-all-btn">' . esc_html__( 'Select all', 'sdequeuerbe' ) . '</a></h3>
            <div class="scripts-loader">
                <table id="sdbe-scripts-table" class="table-selectable">
                    <tr class="table-head">
                    <th>' . esc_html__( 'Handle', 'sdequeuerbe' ) . '</th>
                    <th>' . esc_html__( 'Source', 'sdequeuerbe' ) . '</th>
                    <th>' . esc_html__( 'Dependencies', 'sdequeuerbe' ) . '</th>
                    </tr>';
					
					$i = 0;
					foreach( $wp_scripts->groups as $handle=>$value ) :
						$obj = $wp_scripts->registered[ $handle ];
						echo '<tr data-handle="' . esc_attr( $handle ) . '"><td>' . esc_attr( $handle ) . '</td><td>' . esc_url( $obj->src ) . '</td><td>' . implode( ', ', $obj->deps ) . '</td></tr>';
						$i++;
					endforeach;		
					
                echo '</table>
            </div>
        </div>';
        ?>
                                </div><!-- /.col-66 -->
                                <div class="sd-col col-33">
                                <?php echo '<div id="scbe-dequeue-wrap" class="sd-portlet">
            <h3>' . esc_html__( 'Scripts added for dequeue', 'sdequeuerbe' ) . '<span id="script-dequeue-count-be" class="sd-count"></span>
            <span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'Select scripts to remove from dequeue list and then Save Changes', 'sdequeuerbe' ) . '</span></span>
            <a id="select-dq-scripts-be" href="#" class="select-all-btn">' . esc_html__( 'Remove all', 'sdequeuerbe' ) . '</a></h3>
            <ul id="sdbe-scripts-for-dequeue" class="scripts-view">' . $sc_sel_li . '</ul>
        </div>';

        echo '<div id="scbe-dequeued-wrap" class="sd-portlet">
        <h3>' . esc_html__( 'Scripts successfully dequeued', 'sdequeuerbe' ) . '<span id="script-dequeued-count-be" class="sd-count"></span>
        <span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'The following scripts were dequeued successfully.', 'sdequeuerbe' ) . '</span></span></h3>
        <ul id="sdbe-scripts-dequeued" class="file-list list-success"></ul></div>';

        echo '<div id="scbe-notdequeued-wrap" class="sd-portlet">
        <h3>' . esc_html__( 'Scripts not dequeued', 'sdequeuerbe' ) . '<span id="script-notdequeued-count-be" class="sd-count"></span>
        <span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'The following scripts were not dequeued because other scripts may be dependent on these files or these are system core files.', 'sdequeuerbe' ) . '</span></span></h3>
        <ul id="sdbe-scripts-not-dequeued" class="file-list list-error"></ul>
        </div>';
        ?>
                                </div><!-- /.col-33 -->
                            </div><!-- /.sd-row -->
                        </div><!-- /#sdbe_scripts -->
                        <div id="sdbe_styles" class="sd-tabbed-content">
                            <div class="sd-row">
                                <div class="sd-col col-66">
                                <?php echo '<div id="stbe-file-table" class="file-table-wrap-be">
            <h3>' . esc_html__( 'CSS files detected in backend', 'sdequeuerbe' ) . '<span id="style-detected-count" class="sd-count">' . count( $wp_styles->groups ) . '</span><span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'Select stylesheets to add to dequeue list and then Save Changes.', 'sdequeuerbe' ) . '</span></span><a id="select-all-styles-be" href="#" class="select-all-btn">' . esc_html__( 'Select all', 'sdequeuerbe' ) . '</a></h3>
            <div class="scripts-loader">
                <table id="sdbe-styles-table" class="table-selectable">
                    <tr class="table-head">
                    <th>' . esc_html__( 'Handle', 'sdequeuerbe' ) . '</th>
                    <th>' . esc_html__( 'Source', 'sdequeuerbe' ) . '</th>
                    <th>' . esc_html__( 'Dependencies', 'sdequeuerbe' ) . '</th>
                    </tr>';
					
					$i = 0;
					foreach( $wp_styles->groups as $handle=>$value ) :
						$obj = $wp_styles->registered[ $handle ];
						echo '<tr data-handle="' . esc_attr( $handle ) . '"><td>' . esc_attr( $handle ) . '</td><td>' . esc_url( $obj->src ) . '</td><td>' . implode( ', ', $obj->deps ) . '</td></tr>';
						$i++;
					endforeach;	
					
                echo '</table>
            </div>
        </div>';
        ?>
                                </div><!-- /.col-66 -->
                                <div class="sd-col col-33">
                                <?php echo '<div id="stbe-dequeue-wrap" class="sd-portlet">
            <h3>' . esc_html__( 'CSS added for dequeue', 'sdequeuerbe' ) . '<span id="style-dequeue-count-be" class="sd-count"></span>
            <span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'Select stylesheets to remove from dequeue list and then Save Changes', 'sdequeuerbe' ) . '</span></span>
            <a id="select-dq-styles-be" href="#" class="select-all-btn">' . esc_html__( 'Remove all', 'sdequeuerbe' ) . '</a></h3>
            <ul id="sdbe-styles-for-dequeue" class="scripts-view">' . $st_sel_li . '</ul>
        </div>';

        echo '<div id="stbe-dequeued-wrap" class="sd-portlet">
        <h3>' . esc_html__( 'CSS successfully dequeued', 'sdequeuerbe' ) . '<span id="style-dequeued-count-be" class="sd-count"></span>
        <span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'The following stylesheets were dequeued successfully.', 'sdequeuerbe' ) . '</span></span></h3>
        <ul id="sdbe-styles-dequeued" class="file-list list-success"></ul></div>';

        echo '<div id="stbe-notdequeued-wrap" class="sd-portlet">
        <h3>' . esc_html__( 'CSS not dequeued', 'sdequeuerbe' ) . '<span id="style-notdequeued-count-be" class="sd-count"></span>
        <span class="sd-tooltip">?<span class="sd-tooltip-holder">' . esc_html__( 'The following stylesheets were not dequeued because other CSS files may be dependent on these files or these are system core files.', 'sdequeuerbe' ) . '</span></span></h3>
        <ul id="sdbe-styles-not-dequeued" class="file-list list-error"></ul>
        </div>';
		
		$this->do_settings_sections( 'scripts-dequeuer-backend' );
        ?>
                                </div><!-- /.col-33 -->
                            </div><!-- /.sd-row -->
                        </div><!-- /#sdbe_styles -->
                    </div><!-- /.sd-tabber -->
                </div><!-- /.wrap -->
				<?php
                submit_button('Save Changes');
                ?>
            </form>
        </div><!-- /.wrap -->
	<?php
	}

	// Register Plugin Settings
	function register_settings() {

		// add_settings_section( $id, $title, $callback, $page )
		add_settings_section(
			'sdbe-settings',
			'SDBE Settings',
			'',
			'scripts-dequeuer-backend'
		);

		add_settings_field(
			'sdbe_scripts_selected',
			'',
			array($this, 'sd_hidden_input_cb'),
			'scripts-dequeuer-backend',
			'sdbe-settings',
			'sdbe_scripts_selected'
		);

		add_settings_field(
			'sdbe_scripts_dequeued',
			'',
			array($this, 'sd_hidden_input_cb'),
			'scripts-dequeuer-backend',
			'sdbe-settings',
			'sdbe_scripts_dequeued'
		);

		add_settings_field(
			'sdbe_scripts_not_dequeued',
			'',
			array($this, 'sd_hidden_input_cb'),
			'scripts-dequeuer-backend',
			'sdbe-settings',
			'sdbe_scripts_not_dequeued'
		);

		add_settings_field(
			'sdbe_styles_selected',
			'',
			array($this, 'sd_hidden_input_cb'),
			'scripts-dequeuer-backend',
			'sdbe-settings',
			'sdbe_styles_selected'
		);

		add_settings_field(
			'sdbe_styles_dequeued',
			'',
			array($this, 'sd_hidden_input_cb'),
			'scripts-dequeuer-backend',
			'sdbe-settings',
			'sdbe_styles_dequeued'
		);

		add_settings_field(
			'sdbe_styles_not_dequeued',
			'',
			array($this, 'sd_hidden_input_cb'),
			'scripts-dequeuer-backend',
			'sdbe-settings',
			'sdbe_styles_not_dequeued'
		);

		// register_setting( $option_group, $option_name, $sanitize_callback )
		register_setting( 'sdequeuerbe-settings-group', 'sdequeuerbe_options' );
	}


	function sd_checkbox_cb( $args ) {
		$sd_options = get_option( 'sdequeuerbe_options' );
		$value = isset( $sd_options[ $args['option_name'] ] ) ? $sd_options[ $args['option_name'] ] : false;

        $html  = '<h4>' . esc_attr( $args['title'] ) . '</h4>';
		$html  .= '<fieldset>';
        $html  .= sprintf( '<label for="sdequeuerbe_options[%s]">', $args['option_name'] );
        $html  .= sprintf( '<input type="checkbox" class="checkbox" id="sdequeuerbe_options[%1$s]" name="sdequeuerbe_options[%1$s]" value="1" %2$s />', $args['option_name'], checked( $value, 1, false ) );
        $html  .= sprintf( '%1$s</label>', esc_html( $args['desc'] ) );
        $html  .= '</fieldset>';
        echo $html;
	}

	function sd_hidden_input_cb( $option_name ) {
		$sd_options = get_option( 'sdequeuerbe_options' );
		$value = isset( $sd_options[ $option_name ] ) ? $sd_options[ $option_name ] : '';
		?>
		<input type='hidden' id='sdequeuerbe_options[<?php echo esc_attr( $option_name ); ?>]' name='sdequeuerbe_options[<?php echo $option_name; ?>]' value='<?php echo $value; ?>'>
		<?php
	}

	/**
	 * Customized version of do_settings_sections
	 *
	 * Calls $this->do_settings_fields
	 */
	function do_settings_sections( $page ) {
		global $wp_settings_sections, $wp_settings_fields;

		if ( ! isset( $wp_settings_sections[$page] ) )
			return;

		foreach ( (array) $wp_settings_sections[$page] as $section ) {
			if ( $section['callback'] )
				call_user_func( $section['callback'], $section );

			if ( ! isset( $wp_settings_fields ) || !isset( $wp_settings_fields[$page] ) || !isset( $wp_settings_fields[$page][$section['id']] ) )
				continue;
			echo '<div>';
			$this->do_settings_fields( $page, $section['id'] );
			echo '</div>';
		}
	}

	/**
	 * Customized version of do_settings_fields
	 *
	 * Removed table elements tr, td, etc.
	 */
	function do_settings_fields($page, $section) {
		global $wp_settings_fields;

		if ( ! isset( $wp_settings_fields[$page][$section] ) )
			return;

		foreach ( (array) $wp_settings_fields[$page][$section] as $field ) {
			$class = '';

			if ( ! empty( $field['args']['class'] ) ) {
				$class = ' class="' . esc_attr( $field['args']['class'] ) . '"';
			}

			if ( ! empty( $field['title'] ) ) {
			echo '<h4>' . $field['title'] . '</h4>';
			}
			call_user_func($field['callback'], $field['args']);
		}
	}

}

$scripts_dequeuer_backend_settings = new Script_Dequeuer_Backend_Settings();
?>